@@ -155,6 +155,12 @@ class EC2Tests(LibcloudTestCase, TestCaseMixin):
         driver = EC2NodeDriver(*EC2_PARAMS, region="ap-east-1", signature_version="4")
         self.assertEqual(driver.signature_version, "4")
 
+        driver = EC2NodeDriver(*EC2_PARAMS, region="af-south-1")
+        self.assertEqual(driver.signature_version, "4")
+
+        driver = EC2NodeDriver(*EC2_PARAMS, region="af-south-1", signature_version="4")
+        self.assertEqual(driver.signature_version, "4")
+
     def test_instantiate_driver_with_token(self):
         token = "temporary_credentials_token"
         driver = EC2NodeDriver(*EC2_PARAMS, **{"region": self.region, "token": token})
